@@ -1,23 +1,18 @@
 #-----------------------------------------------------------------
 # pycparser: using_cpp_libc.py
 #
-# Shows how to use the provided 'cpp' (on Windows, substitute for
-# the 'real' cpp if you're on Linux/Unix) and "fake" libc includes
+# Shows how to use 'cpp' (the C pre-processor binary) and "fake" libc includes
 # to parse a file that includes standard C headers.
 #
-# Copyright (C) 2008-2015, Eli Bendersky
+# Eli Bendersky [https://eli.thegreenplace.net/]
 # License: BSD
 #-----------------------------------------------------------------
 import sys
 
 # This is not required if you've installed pycparser into
 # your site-packages/ with setup.py
-#
 sys.path.extend(['.', '..'])
 
-# Portable cpp path for Windows and Linux/Unix
-CPPPATH = 'utils/cpp.exe' if sys.platform == 'win32' else 'cpp'
-
 from pycparser import parse_file
 
 
@@ -28,7 +23,6 @@ if __name__ == "__main__":
         filename = 'examples/c_files/year.c'
 
     ast = parse_file(filename, use_cpp=True,
-            cpp_path=CPPPATH, 
+            cpp_path='cpp',
             cpp_args=r'-Iutils/fake_libc_include')
-    
     ast.show()
